@@ -1,12 +1,12 @@
 shorts_model_fit <- function(model = NULL, observed, predicted, na.rm = FALSE) {
-  resid <- predicted - observed
+  resid <- observed - predicted
 
   # This is needed for the LOOCV option which doesn't return model
   # thus, RSE cannot be computed
-  if(is.null(model)) {
+  if (is.null(model)) {
     RSE <- NA
   } else {
-    RSE = summary(model)$sigma
+    RSE <- summary(model)$sigma
   }
 
   list(
